Type: Package
Title: Response Data for Light Sensors
Version: 0.5.3
Date: 2026-03-12
Maintainer: Pedro J. Aphalo <pedro.aphalo@helsinki.fi>
Description: Spectral response data for broadband ultraviolet and visible radiation sensors. Angular response data for broadband ultraviolet and visible radiation sensors and diffusers used as entrance optics. Data obtained from multiple sources were used: author-supplied data from scientific research papers, sensor-manufacturer supplied data, and published sensor specifications. Part of the 'r4photobiology' suite Aphalo P. J. (2015) <doi:10.19232/uv4pb.2015.1.14>.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
VignetteBuilder: knitr
Depends: R (≥ 4.1.0), photobiology (≥ 0.14.0)
Suggests: knitr (≥ 1.50), rmarkdown (≥ 2.29), photobiologyWavebands (≥ 0.5.3), ggspectra (≥ 0.3.16), ggplot2 (≥ 3.5.1)
LazyLoad: yes
LazyData: yes
ByteCompile: true
Encoding: UTF-8
URL: https://docs.r4photobiology.info/photobiologySensors/, https://github.com/aphalo/photobiologysensors
BugReports: https://github.com/aphalo/photobiologysensors/issues
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-13 20:23:50 UTC; aphalo
Author: Pedro J. Aphalo ORCID iD [aut, cre]
Repository: CRAN
Date/Publication: 2026-03-13 21:50:02 UTC

photobiologySensors: Response Data for Light Sensors

Description

logo

Spectral response data for broadband ultraviolet and visible radiation sensors. Angular response data for broadband ultraviolet and visible radiation sensors and diffusers used as entrance optics. Data obtained from multiple sources were used: author-supplied data from scientific research papers, sensor-manufacturer supplied data, and published sensor specifications. Part of the 'r4photobiology' suite Aphalo P. J. (2015) doi:10.19232/uv4pb.2015.1.14.

Details

Data for spectral response for different types of broadband sensors are stored as objects of class sensor_spct as collection members in an object of class sensor_mspct. In addition to the spectra the package provides character vectors of names to be used as indexes to extract spectra from the collection.

Data for angular response for different types of broadband sensors and some diffusers used as entrance optics for spectrometers are stored as objects of class data.frame as members of a list. In addition to the list of data frames, the package provides character vectors of names to be used as indexes to extract the data frames from the named list.

The data in this package are not original. Some have been provided by authors of scientific publications and manufacturers. However, most of the spectra have been digitized from manufacturer's brochures and manuals available on web sites.

Warning!

The spectral data included in this package are not all based on supplier's specifications and are only for information. The exact response spectrum depends to some extent on testing conditions, but more importantly varies among individual sensor units. Spectral specifications are usually given as typical values. All the sensors for which data are presented here need periodic calibration. In other words, the data provided here are not a substitute for actual calibration under measuring conditions for each individual sensor unit. For less demanding situations like roughly assessing the suitability of sensors or the need or not of a transfer calibration, the data are good enough. They can be especially useful in teaching.

Data and their units of expression

Data are normalized to one at the wavelength of maximum response to energy. Wavelengths are expressed in nanometres as required by the classes from package 'photobiology' used to store the data. The User Guide shows how to re-scale and normalize the data using other criteria.

Author(s)

Maintainer: Pedro J. Aphalo pedro.aphalo@helsinki.fi (ORCID)

References

Aphalo, Pedro J. (2015) The r4photobiology suite. UV4Plants Bulletin, 2015:1, 21-29. doi:10.19232/uv4pb.2015.1.14.

See Also

Useful links:

Examples

library(photobiology)
library(photobiologyWavebands)
library(ggspectra)

names(sensors.mspct)

licor_sensors
par_sensors
intersect(par_sensors, licor_sensors)

photon_as_default()

response(sensors.mspct$LICOR_LI_190R, w.band = PAR(), quantity = "contribution.pc")

autoplot(sensors.mspct$LICOR_LI_190R, w.band = PAR(), label.qty = "contribution.pc")

names(diffusers.lst)

cosine_diffusers


Entrance optics

Description

A vector of names useful for extracting subsets of angular response data from the diffusers.lst object.

Usage

all_diffusers

cosine_diffusers

dome_diffusers

entrance_optics

sensor_optics

ic_optics

ideal_optics

Format

An object of class character of length 18.

An object of class character of length 16.

An object of class character of length 2.

An object of class character of length 3.

An object of class character of length 9.

An object of class character of length 3.

An object of class character of length 3.

Details

Irradiance measurements require diffusers or sensors with a response proportional to the cosine of the angle of light incidence, i.e., varying between a maximum and zero over 180 degrees in 3D. In practice no real diffusers achieve this over 180 degrees, and only the best ones approach the expected response over an angle of 160 to 170 degrees. Such entrance optics are described as cosine corrected and data for them can be extracted from diffusers.lst using cosine_diffusers. The response expected is given by the projected light exposed area under a collimated beam: A_\mathrm{p} = A_\mathrm{max} \times \cos(z) where z is the angle of incidence relative to the normal to the plane of the entrance optics or diffuser. For a horizontal sensor, z is the zenith angle of the sun.

Hemispherical scalar irradiance (or hemispherical fluence rate) requires an entrance optic with a response that varies with the angle of incidence between a maximum and its half over 180 degrees in 3D. Such sensors or diffusers are seldom available off-the-shelf. Data for them can be extracted from diffusers.lst using dome_diffusers. The response expected is given by the projected light exposed area under collimated light: A_\mathrm{p} = A_\mathrm{max} \times 0.5 \times (1 + \cos(z)) where z is the angle of incidence relative to the normal to the plane of the entrance optics or diffuser.

Scalar irradiance (or fluence rate) measurements require a diffuser with response invariant over 360 degrees in 3D. Real sensors of this geometry have a blind spot as a fibre or a detector have to be attached to them. The response expected is given by the projected light exposed area under collimated light: A_\mathrm{p} = A_\mathrm{max} \times 1 for all angles of incidence.

The angular response of ready-to-deploy broadband sensors can be extracted from diffusers.lst by sensor_diffusers. With a few exceptions these sensors are designed to measure irradiance.

The angular response of entrance optics suitable for use with spectrometers can be extracted from diffusers.lst by entrance_optics.

The angular response of bare sensors sold as electronic components including integrated circuits and photodiodes can be extracted from diffusers.lst by ic_optics. In some cases they approximate a cosine response except at high z angles. In other cases they have a much narrower angle of view.

The angular response expected based on physical quantity definitions can be extracted from diffusers.lst by ideal_optics. They have been computed using the equations shown above.

Responses are expressed relative to that for the maximum projected as fractions of one.

See Also

Data in diffusers.lst and function angular_response().

Examples

all_diffusers


'ams' sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

ams_sensors

Format

An object of class character of length 7.

Details

TSL254R light-to-voltage optical sensor combining a photodiode and a transimpedance amplifier, sold as electronic components. The spectral response is nearly identical for type TSL250, TSL251 and TSL252. (part is no longer in production.)

TSL257 high-sensitivity low-noise light-to-voltage optical converter that combines a photodiode and a transimpedance amplifier, sold as electronic components.

AS7263, AS7331, AS7341, AS7343, TSL2501 are miniature multichannel sensors in SMD packages. In addition to photodiodes and optical filters they contain analogue signal amplifiers and analogue to digital conversion circuits. The data are returned digitally through an I2C serial interface. In some of them analogue gain and ADC integration time can be set through the I2C interface.

BPX65 is a silicon (Si) photodiode in T18 can package.

Manufacturer: ams-OSRAM AG, Austria. https://ams-osram.com

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Data sheet for TSL254R (TAOS, TAOS071C - SEPTEMBER 2007)

Data sheet for TSL257 (v1-00, 2016-Jul-25)

Data sheet for TSL2591 (ams DS000338, v3-00, 2023-Feb-08)

Data sheet for AS7263 (ams DS000476, v4-00, 2022-Nov-30)

Data sheet for AS7331 (ams DS001047, v4-00, 2023-Mar-24)

Data sheet for AS7341 (ams DS000504, v3-00, 2020-Jun-25)

Data sheet for AS7343 (ams DS001046, v6-00, 2023-Jun-07)

Data sheet for BPX65 (Version 1.4, 2023-01-24)

See Also

sensors.mspct

Examples


ams_sensors


Analytik-Jena sensors.

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

analytik_sensors

Format

An object of class character of length 0.

Details

UVX-25, UVX-31 and UVX-36 sensor for UV-C, UV-B and UV-A radiation, respectively. Detection system includes optical filters and a Si photodiode.

Manufacturer: Analytik Jena US LLC, Upland, CA, USA (former UVP) https://www.analytik-jena.com/ or https://www.uvp.com/.

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Product manual: 'UVP UVX Radiometer: Instruction Guide' (figures 6, 7 and 8).

See Also

sensors.mspct

Examples


analytik_sensors


Angular response

Description

Angular response of idealized entrance optics used in light measurements.

Usage

angular_response(
  elevation.angle = 90,
  geometry = "cosine",
  zenith.angle = 90 - elevation.angle,
  diameter = NULL
)

Arguments

elevation.angle, zenith.angle

numeric The elevation angle of a point light source such as the sun or its zenith angle [degrees].

geometry

character The type of entrance optics, one of "flat disk", "cosine", "dome", "hemisphere", "ball", or "sphere".

diameter

numeric The diameter of the entrance optics. If NULL, the default, a relative value is returned.

Details

The maximum projected area (A_\mathrm{max}) is always computed for a circle of diameter d as A_\mathrm{max} = \pi \times d^2 / 4 when computing actual projected areas, or set to A_\mathrm{max} = 1 for computation of relative values.

The cosine response for a flat disk is computed as

A_\mathrm{p} = A_\mathrm{max} \times \cos(z)

The hemispherical response for a dome is computed as

A_\mathrm{p} = A_\mathrm{max} \times 0.5 \times (1 + \cos(z))

The spherical response for a "ball" is computed as

A_\mathrm{p} = A_\mathrm{max} \times 1

See Also

all_diffusers and diffusers.lst for data for real sensors and entrance optics.

Examples

angular_response(45)
angular_response(45, "cosine")
angular_response(45, "dome")
angular_response(45, "sphere")
angular_response(c(0, 30, 60, 90))
angular_response(-c(0, 30, 60, 90))
angular_response(c(0, 30, 60, 90), "dome")
angular_response(c(0, 30, 60, 90), "sphere")


apogee broadband sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

apogee_sensors

Format

An object of class character of length 6.

Details

apogee SQ-100X-SS: Original Quantum Sensor.

apogee SQ-500-SS: Full-Spectrum Quantum Sensor

apogee SQ-610-SS 400-750nm ePAR Sensor (extended PAR quantum)

apogee SU-200-SS: UV-A Sensor (UV-A, "energy")

apogee S2-131-SS Red and Far-Red Sensor, Red channel, quantum

apogee S2-131-SS Red and Far-Red Sensor, Far-Red channel, quantum

Manufacturer: Apogee Instruments, Inc., Logan, UT, USA.

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

https://www.apogeeinstruments.com/quantum/ visited on 2023-10-10. (manufacturers product on-line specifications).

See Also

sensors.mspct

Examples


apogee_sensors


'Berger' UV-Biometer

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

berger_sensors

Format

An object of class character of length 1.

Details

One of the early erythemaly-weighted UV broadband sensors. The 'Berger' UV-Biometer (Fig. 1 in Berger, 1994).

From Solar Light Co., Inc., Philadelphia, USA.

Note

Digitized with 'enguage' from manufacturers brochures. These are approximate data, both because of the digitizing process, and because they are either typical values or for a particular sensor unit. Individual sensor units are expected to differ to some degree in spectral response.

References

Berger, Daniel (n.d., ca. 1994) A comparison of Spectroradiometers to Radiometers for UV Radiation Measurements. Solar Light Co., Inc., Philadelphia.

See Also

sensors.mspct

Examples

berger_sensors


Delta-T sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

deltat_sensors

Format

An object of class character of length 1.

Details

From figure in manufacturer's manual. The Delta-T BF5 in a broadband diffuse and total irradiance sensor calibrated for photosynthetically active radiation (PAR). It is based on seven Si photodiodes as a shading dome with a custom pattern of openings.

Manufacturer: Delta-T Devices Ltd, CAMBRIDGE CB25 0EJ, UK https://delta-t.co.uk/

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Manufacturer's User Manual Version: 1.0 dated Nov 2010

See Also

sensors.mspct

Examples

deltat_sensors


Angular response of sensors

Description

A collection of angular response data for selected broadband sensors used for measuring ultraviolet and visible radiation and of cosine diffusers used with spectrometers.

Usage

diffusers.lst

Format

A list object containing data.frame objects as named members.

Each member spectrum contains three variables:

Details

Each data frame in the list contains three variables, angle.deg (degrees) at either regular or irregular intervals, response relative to the maximum (as a fraction of one) and response relative to a perfect cosine response (as a fraction of one). Data are either from manufacturer specifications or independent measurements reported in the scientific literature.

Note

Values are only good as reference, as individual sensors and diffusers deviate to a smaller or larger extent from typical or mean responses for their type. Variability is also reflected in some cases as an asymmetry in opposite angles away from the vertical.

See Also

Vectors of names in all_diffusers and function angular_response().

Examples

names(diffusers.lst)


Types of sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

electronic_components

Format

An object of class character of length 15.

Details

The sensors pointed at by this vector are those sold as electronic components and used to construct sensors that can be deployed when interfaced to other electronic components, possibly combined with optical filters and entrance optics and protected inside a case or enclosure.

See Also

sensors.mspct

Examples

electronic_components


Idealized sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

ideal_sensors

Format

An object of class character of length 2.

Details

Flat spectral response to spectral energy irradiance and to spectral photon irradiance.

Note

Exact values based on physical principles.

References

KJ McCree. The action spectrum, absorbance and quantum yield of photosynthesis in crop plants. Agricultural Meteorology. 1971/72 Vol 9, pp 191-216

See Also

sensors.mspct

Examples

ideal_sensors


Spectral response of image sensors

Description

A collection of response spectra for various image sensors and digital cameras responsive to ultraviolet, visible, NIR and/or SWIR radiation. Each spectrum in the collection contains two variables, wavelengths (nm) at irregular intervals and spectral responsiveness (in photon units = quantum efficiency). Spectral data are normalized to one at the wavelength of maximum quantum efficiency only when this is how the original source published the data.

Usage

image_sensors.mspct

Format

A response_mspct object containing response_spct objects as named members.

Spectral objects for monochrome image sensors contain two numeric variables, with quantum efficiency in some cases in relative energy units:

Spectral objects for colour image sensors contain the spectra in long form with two numeric variables, and in addition a factor with channel ids:

The spectral objects contain, in addition to the spectral data, metadata stored in R attributes sensor.properties, what.measured, how.measured, and comment.

See Also

response_spct and response_mspct

Examples

names(image_sensors.mspct)


Irradian Sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

irradian_sensors

Format

An object of class character of length 4.

Details

Irradian sensors DA211A-Cos (UV-A), DA211B2-Cos (UV-B), DV211Q-Cos (PAR), DV211E-Cos (pyranometer).

Manufacturer: Irradian Ltd., Tranent, East Lothian, Scotalnd, U.K.

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Manufacturer's brochure for 'DA211-v2a' not dated, downloaded on 2026-03-09. Manufacturer's brochure for 'DV211-v2a' not dated, downloaded on 2026-03-09.

KJ McCree. The action spectrum, absorbance and quantum yield of photosynthesis in crop plants. Agricultural Meteorology. 1971/72 Vol 9, pp 191-216

See Also

sensors.mspct

Examples

irradian_sensors


Kipp Radiometers.

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

kipp_sensors

Format

An object of class character of length 6.

Details

Kipp CM21 pyranometer. Thermopile-detector based, class A.

Kipp CUV 5 Broadband UV Radiometer: Detection system includes optical filters and a photodiode.

Kipp PQS 1 PAR Quantum Sensor: Detection system includes optical filters and a photodiode.

UVS-A-T Radiometer, UVS-B-T Radiometer, Kipp UVS-E-T Erythemal Radiometer: The detection system includes optical filters and a phosphor that determine the spectral response. The phosphor is very sensitive to low levels of ultraviolet radiation and is stimulated by the UV to emit green light, which is detected by a photodiode. The system is temperature stabilised at +25 °C to prevent changes in spectral response and sensitivity with variations in the ambient conditions.

Manufacturer: Kipp & Zonen B.V., Delftechpark 36, 2628 XH Delft, Nederlands. https://www.kippzonen.com/

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Brochure 'Broadband UV Radiometers', Brochure 'PQS 1 PAR Quantum Sensor', Brochure 'Broadband UV Radiometers'. Rodziewicz, T., Rajfur, M. (2019) Numerical procedures and their practical application in PV modules analyses. Part I: air mass. Opto-Electronics Review, Vol. 27, No. 1 39-57

See Also

sensors.mspct

Examples


kipp_sensors


LI-COR sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

licor_sensors

Format

An object of class character of length 6.

Details

In the LI-190SA and LI-190 PAR quantum sensor (PAR = photosynthetically active radiation) colored glass filters are used to tailor the silicon photodiode response to the desired quantum response. They have the same spectral response.

The type of filter used in the LI-190R PAR quantum sensor is not described, but improves the spectral response compared to the LI-190.

The LI-200SA features a silicon photovoltaic detector. This is not a true 'pyranometer' and should be used only in sunlight, and calibrated in sunlight.

The LI-210SA Photometric Sensor utilizes a filtered silicon photodiode to provide a spectral response that matches the CIE curve within ± 5 light sources.

The LI-210R Photometric Sensor utilizes a filtered silicon photodiode to provide a spectral response that matches the CIE curve.

Manufacturer: LI-COR Inc., Lincoln, Nebraska https://www.licor.com/env/

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

LI-COR (2005) Instruction Manual 'LI-COR Terrestrial Radiation Sensors'. LI-COR (2015) Technical Note 'Why Upgrade to the "R" Light and Radiation Sensors?'

See Also

sensors.mspct

Examples

licor_sensors


Spectral response of sensors

Description

A collection of response spectra for various broadband sensors used for measuring ultraviolet and visible radiation. Each spectrum in the collection contains two variables, wavelengths (nm) at either regular or irregular intervals and spectral responsiveness (in energy units). Spectral data are in most cases normalized to one at the wavelength of maximum energy responsivity. Absolute calibration values are given only for data from a publication which reports on multiple units of the same type.

Usage

sensors.mspct

Format

A response_mspct object containing response_spct objects as named members.

Spectral objects for single channel sensors contain two numeric variables, with responsivity in most cases in relative energy units:

Spectral objects for multichannel sensors contain the spectra in long form with two numeric variables, and in addition a factor with channel ids:

The spectral objects contain, in addition to the spectral data, metadata stored in R attributes sensor.properties, what.measured, how.measured, and comment.

Note

In addition to this object containing the spectral data, this package provides character vectors useful for sub-setting spectra by supplier, type, colour, etc.

See Also

source_spct and source_mspct

Examples

names(sensors.mspct)


sglux broadband sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

sglux_sensors

Format

An object of class character of length 7.

Details

sglux SG01D-A UV-A broadband sensor (filtered SiC sensor).

sglux SG01D-B UV-B broadband sensor (filtered SiC sensor, VIS-blind).

sglux SG01D-C UV-C broadband sensor (filtered SiC sensor, "solar-blind").

sglux SG01L SiC broadband sensor (SiC sensor not filtered).

sglux TOCON blue 4 blue light broadband sensor (pre-amplified GaP detector).

TOCON preamplified sensors with similar spectral response as the diodes are also available from sglux. The blue light sensor is only available as preamplified TOCON. Sensors are available in different configurations with different sensitivity and with different angular responses, and encased to resist different environmental conditions.

Manufacturer: sglux GmbH, Berlin, Germany. https://sglux.de/en/

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

personal communication from Dr. Stefan Langer.

See Also

sensors.mspct

Examples


sglux_sensors


Skye-Instruments Sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

skye_sensors

Format

An object of class character of length 11.

Details

Skye PAR quantum Sensor SKP215, Skye PAR energy sensor SKE510, Skye Lux sensor SKL310, Skye PAR 'Special' Sensor SKP210, Skye PAR quantum Sensor SKP215, Skye 660/730 Sensor (Red/Far Red) Sensor SKR110 (red and far-red channels), Skye Pyranometer Sensor SKS1110, Skye UV-A Sensor Sensor SKU421, Skye UV-A Sensor Sensor SKU421 V. 3, Skye UV-B Sensor Sensor SKU430 V. 3, Skye UVI Sensor Sensor SKU440 V. 3.

Manufacturer: Skye Instruments, Llandrindod Wells, Powys, UK. As of 2026, out of business.

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Manufacturer's brochure for 'SKP215' dated 2007-10-03. Manufacturer's brochure for 'SKP510' dated 2007-10-02. Manufacturer's brochure for 'SKL310' dated 2007-10-09 Manufacturer's brochure for 'SKP210' dated 2007-10-03 Manufacturer's brochure for 'Skye 660/730 Sensor (Red/Far Red) Sensor SKR110' dated 2007-10-09 Manufacturer's brochure 'Skye Pyranometer Sensor SKS1110' dated 2009-08-19 Manufacturer's 'UV-A, UV-B & UV-I Sensors' Manual, Iss. 1.1 Manufacturer's 'SKU 421 UVA Sensor' V. 3 brochure, not dated, dowloaded on 2015-01-24 Manufacturer's 'SKU 430 UVB Sensor' V. 3 brochure, not dated, dowloaded on 2015-01-24 Manufacturer's 'SKU 440 UV Index Sensor' V. 3 brochure, not dated, dowloaded on 2015-01-24

KJ McCree. The action spectrum, absorbance and quantum yield of photosynthesis in crop plants. Agricultural Meteorology. 1971/72 Vol 9, pp 191-216

See Also

sensors.mspct

Examples

skye_sensors


Solar Light sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

solarlight_sensors

Format

An object of class character of length 3.

Details

Solar Light UVB biometer model 501 (units with high and low UV-A sensitivity, and a typical unit). Data from an intercomparison.

Manufacturer: Solar Light Company, Glenside, PA, U.S.A. https://www.solarlight.com/

Note

Data kindly made available by Lasse Ylianttila. These are the responses from a unit with higher and lower response to UVA radiation than typical units, as well as the response for a typical unit as observed in an instrument intercomparison.

References

Leszczynski K, Jokela K, Ylianttila L, Visuri R, Blumthaler M. 1997. Report of the WMO/STUK Intercomparison of erythemally-weighted solar UV radiometers (Spring/Summer 1995, Helsinki, Finland). WMO-GAW Report No. 112, 90 pages.

Leszczynski K, Jokela K, Ylianttila L, Visuri R, Blumthaler M. 1998. Erythemally weighted radiometers in solar UV monitoring: results from the WMO/STUK Intercomparison. Photochem. Photobiol. 67(2):212-221.

See Also

sensors.mspct

Examples


solarlight_sensors


Solarmeter devices

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

solarmeter_sensors

Format

An object of class character of length 1.

Details

SOLARMETER MODEL 6.0 UV METER: Silicon Carbide (SIC) Photodiode packaged in hermetically sealed UV glass window cap. Interference filter coating (Metal Oxide) blocks most UVA.

Manufacturer: Solartech, Inc., 26101 Harbour Pointe Dr N., Harrison Twp, MI 48045, As of 2026 a part of Solar Light Company, LLC. https://www.solarlight.com/.

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Digitized from ⁠SM60graph.gif⁠ obtained from ⁠https://www.solarmeter.com/⁠ on 20 December 2013.

See Also

sensors.mspct

Examples


solarmeter_sensors


Specmeters broadband sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

specmeters_sensors

Format

An object of class character of length 1.

Details

Specmeters 3415F PAR quantum sensor.

Manufacturer: Spectrum Technologies, Inc., Aurora, IL, USA. https://www.specmeters.com/

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Quantum Light Meters PRODUCT MANUAL (R 06/14). https://www.specmeters.com/

See Also

sensors.mspct

Examples


specmeters_sensors


Thies Clima sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

thiesclima_sensors

Format

An object of class character of length 1.

Details

Thies Clima E1.c broadband UVB sensor

Manufacturer: Thies Clima, Göttingen, DE. https://www.thiesclima.com/

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Data sheet for TSL254R (TAOS, TAOS071C - SEPTEMBER 2007)

Data sheet for TSL257 (v1-00, 2016-Jul-25)

Data sheet for TSL2591 (ams DS000338, v3-00, 2023-Feb-08)

Data sheet for AS7263 (ams DS000476, v4-00, 2022-Nov-30)

Data sheet for AS7331 (ams DS001047, v4-00, 2023-Mar-24)

Data sheet for AS7341 (ams DS000504, v3-00, 2020-Jun-25)

Data sheet for AS7343 (ams DS001046, v6-00, 2023-Jun-07)

Data sheet for BPX65 (Version 1.4, 2023-01-24)

See Also

sensors.mspct

Examples


thiesclima_sensors


Sensors responsive to different wavebands

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

uv_sensors

uvc_sensors

uvb_sensors

erythemal_sensors

uva_sensors

par_sensors

epar_sensors

vis_sensors

photometric_sensors

shortwave_sensors

pyranometer_sensors

red_sensors

far_red_sensors

blue_sensors

green_sensors

multichannel_sensors

Format

An object of class character of length 27.

An object of class character of length 2.

An object of class character of length 6.

An object of class character of length 10.

An object of class character of length 8.

An object of class character of length 9.

An object of class character of length 1.

An object of class character of length 3.

An object of class character of length 3.

An object of class character of length 4.

An object of class character of length 4.

An object of class character of length 2.

An object of class character of length 2.

An object of class character of length 1.

An object of class character of length 1.

An object of class character of length 11.

Details

The sensors pointed at by each of these vectors are sensitive to light of a certain colour within visible radiation (VIS) or to different bands of ultraviolet (UV) or infrared (IR) radiation.

See Also

sensors.mspct

Examples

uv_sensors # ultraviolet
uvc_sensors # ultraviolet-C
uvb_sensors # ultraviolet-B
uva_sensors # ultraviolet-A
epar_sensors # extended photosynthetically active radiation
par_sensors # photosynthetically active radiation
vis_sensors # "visual" light sensors
shortwave_sensors
red_sensors
far_red_sensors
blue_sensors
multichannel_sensors

# select PAR sensors
sensors.mspct[par_sensors]


'Vishay' sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

vishay_sensors

Format

An object of class character of length 1.

Details

Vishay VEML6075 UVA and UVB sensor with I2C digital interface. Two spectra, one for each channel.

Manufacturer: VISHAY INTERTECHNOLOGY, INC. Shelton, CT, USA. https://www.vishay.com/.

Note

Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.

References

Document Number: 84304, Rev. 1.2, 23-Nov-16; VISHAY INTERTECHNOLOGY, INC.

See Also

sensors.mspct

Examples


vishay_sensors


Vital Technologies sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

vitaltech_sensors

Format

An object of class character of length 1.

Details

Vital "Blue Wave" BW-20 UV-B "erythemal" radiometer. Data for a specific unit included in a sensor intercomparison event.

Manufacturer: Vital Technologies, Canada. Company no longer in business.

Note

Data kindly made available by Lasse Ylianttila.

References

Leszczynski K, Jokela K, Ylianttila L, Visuri R, Blumthaler M. 1997. Report of the WMO/STUK Intercomparison of erythemally-weighted solar UV radiometers (Spring/Summer 1995, Helsinki, Finland). WMO-GAW Report No. 112, 90 pages.

Leszczynski K, Jokela K, Ylianttila L, Visuri R, Blumthaler M. 1998. Erythemally weighted radiometers in solar UV monitoring: results from the WMO/STUK Intercomparison. Photochem. Photobiol. 67(2):212-221.

See Also

sensors.mspct

Examples


vitaltech_sensors